if not MenuHelperHelper then return end

-- This is the settings table, its structure is the menu structure
Profile_menu = {

	-- This creates an 'input' item where user will be able to enter text
	name = 'John Smith',
	
	-- This creates a 'slider' where user will be able to set a number
	age = 35, -- The value user sets is rounded down
	
	-- This creates a submenu with two 'sliders' inside
	more = {
			height = 180,
			weight = 85
		},
	
	-- This becomes a 'multiple choice' item, 'value' is the default value
	sex = { 'male', 'female', 'other', value = 1},
	
	-- This creates a 'toggle'
	married = true,
	
	-- This creates a 'divider' (empty space)
	gap = '_ 20',

	-- This creates a button with the function executed when user clicks it
	notes = function(item) -- The menu item (the button) is passed as the argument
		QuickMenu:new(
					'Notes', 
					'No notes attached.',
					 {{text = 'OK', is_cancel_button = true}}	
				):Show()
	end
}

-- This is to be used to configure some items (optional)
-- Set this before calling CreateMenu()
MenuHelperHelper._tweaks = {

	-- Pull name to the top of the menu
	name = { priority = 10 },
	
	-- Set the divider to be right below the name
	gap = { priority = 9 },
	
	-- Set age slider to be 0-120
	age = {slider_min = 0, slider_max = 120},
	
	-- Set height to 50-220 and weight to 30-150
	height = {slider_min = 50, slider_max = 220},
	weight = {slider_min = 30, slider_max = 150},

	-- 'default' can be used to apply something to all items
	-- It's only here as a list of available parameters right now
	default = {
		priority = nil, -- The higher this is, the higher the item is in the menu
		localized = nil, -- If localized string should be used (if not you'll see names like 'profile_menu_age')
		slider_min = nil,
		slider_max = nil,
		show_value = nil, -- If slider should display the number value set on it
		divider = nil, -- If false, divider formatted string ('_ 20') will be treated as a normal string
		callback = nil, -- Sets the function to call when the value is changed
		
		-- These are only for 'default'
		instant_callback = nil, -- If true, callback is called after every change, otherwise after user exits the menu
		save_only_changed = nil -- If true, settings set as default won't be saved to the save file
	}
}

-- This sets up the menu and hooks everything
MenuHelperHelper:CreateMenu(Profile_menu, 'profile_menu', 'Profile.txt', function(settings) 
	Profile_menu = settings -- Replace the settings table with it's new version
end) --, 'profile.json')

-- CreateMenu( settings table | new menu ID | save file name | callback function | localization file name )

-- Settings will be saved in mods/saves automatically
-- Calling CreateMenu() loads up the save file and modifies the original settings table

-- Callback is called when user exits the menu, unless 'instant_callback' tweak is enabled
-- Callback gets the new (changed) version of the settings table as the argument

-- If localization file name is present, a localization file will be generated and saved in mod/saves under that name
-- That only leaves to fill it with the localized text
-- See 'profile - generated.json' - that's what it'll look like
-- Remove that argument before releasing the mod!



-- Additional stuff

-- SetValue()
-- MenuHelperHelper:SetValue('profile_menu:more:height', 200, ':')
-- Visually sets certain menu item to the certain value
-- The last argument (separator) defaults to colon and can be omitted
-- Do this for any settings you change in the scripts outside the menu, so that the menu represents the actual values
-- (do not uncomment this here, menus are not created yet)

-- The menu saves settings automatically
-- If you want to force it to save the settings, call MenuCallbackHandler:MHH_save_my_menu_id()
-- Replace 'my_menu_id' with your menu ID


-------------------------------------------------------------------------------------

-- This below is used to load the localization file
-- This is not a part of the example mod
local thisPath
local thisDir
local function Dirs()
	thisPath = debug.getinfo(2, "S").source:sub(2)
	thisDir = string.match(thisPath, '.*/')
end
Dirs()
Dirs = nil

Hooks:Add("LocalizationManagerPostInit", "ProfileMenu", function(loc)
	LocalizationManager:load_localization_file(thisDir..'loc.json')
end)